@@ -284,33 +284,6 @@
 #'   ```
 "ison_physicians"
 
-## US States ####
-
-#' One-mode undirected network of US state contiguity (Meghanathan 2017)
-#'
-#' @description
-#'   This network is of contiguity between US states.
-#'   States that share a border are connected by a tie in the network.
-#'   The data is a network of 107 ties among 50 US states (nodes).
-#'   States are named by their two-letter ISO-3166 code.
-#'   This data includes also the names of the capitol cities of each state,
-#'   which are listed in the node attribute 'capitol'.
-#' @docType data
-#' @keywords datasets
-#' @name ison_usstates
-#' @usage data(ison_usstates)
-#' @references
-#'   Meghanathan, Natarajan. 2017. 
-#'   "Complex network analysis of the contiguous United States graph." 
-#'   _Computer and Information Science_, 10(1): 54-76.
-#'   \doi{10.5539/cis.v10n1p54}
-#' @format
-#'   ```{r, echo = FALSE}
-#'   ison_usstates
-#'   ```
-"ison_usstates"
-
-
 ## High-tech ####
 
 #' One-mode multiplex, directed network of managers of a high-tech company (Krackhardt 1987)
@@ -486,13 +459,13 @@
 #'   Interaction can be cooperative or conflictual.
 #' @docType data
 #' @keywords datasets
-#' @name ison_lotr
-#' @usage data(ison_lotr)
+#' @name fict_lotr
+#' @usage data(fict_lotr)
 #' @format
 #'   ```{r, echo = FALSE}
-#'   ison_lotr
+#'   fict_lotr
 #'   ```
-"ison_lotr"
+"fict_lotr"
 
 ## Harry Potter ####
 
@@ -511,8 +484,8 @@
 #'   gender, and their house assigned by the sorting hat are included.
 #' @docType data
 #' @keywords datasets
-#' @name ison_potter
-#' @usage data(ison_potter)
+#' @name fict_potter
+#' @usage data(fict_potter)
 #' @references
 #'   Bossaert, Goele and Nadine Meidert (2013). 
 #'   "'We are only as strong as we are united, as weak as we are divided'. A dynamic analysis of the peer support networks in the Harry Potter books." 
@@ -520,30 +493,39 @@
 #'   \doi{10.4236/ojapps.2013.32024}
 #' @format
 #'   ```{r, echo = FALSE}
-#'   ison_potter
+#'   fict_potter
 #'   ```
-"ison_potter"
+"fict_potter"
 
 ## Game of Thrones ####
 
 #' One-mode Game of Thrones kinship (Glander 2017)
 #'
 #' @description
-#'   Shirin Glander extended a data set on character deaths in the TV series Game of Thrones
-#'   with the kinship relationships between the characters, by scraping "A Wiki of Ice and Fire"
-#'   and adding missing information by hand.
+#'   The original dataset was put together by Erin Pierce and Ben Kahle for an
+#'   assignment for a course on Bayesian statistics.
+#'   The data included information on when characters died in the Song of Ice
+#'   and Fire books,
+#'   and some predictive factors such as whether they were nobles, married, etc.
+#'   Shirin Glander extended this data set on character deaths in the TV series 
+#'   Game of Thrones with the kinship relationships between the characters, 
+#'   by scraping "A Wiki of Ice and Fire" and adding missing information by hand.
+#'   There is certainly more that can be done here.
 #' @docType data
 #' @keywords datasets
-#' @name ison_thrones
-#' @usage data(ison_thrones)
+#' @name fict_thrones
+#' @usage data(fict_thrones)
 #' @references
-#'   Glander, Shirin (2017). 
+#'   Pierce, Erin, and Ben Kahle. 2015.
+#'   "\href{http://allendowney.blogspot.com/2015/03/bayesian-survival-analysis-for-game-of.html}{Bayesian Survival Analysis in A Song of Ice and Fire}".
+#'   
+#'   Glander, Shirin. 2017. 
 #'   "\href{https://datascienceplus.com/network-analysis-of-game-of-thrones/}{Network analysis of Game of Thrones}".
 #' @format
 #'   ```{r, echo = FALSE}
-#'   ison_thrones
+#'   fict_thrones
 #'   ```
-"ison_thrones"
+"fict_thrones"
 
 ## Star Wars ####
 
@@ -584,33 +566,31 @@
 
 ## Friends ####
 
-#' One-mode Friends character connections (McNulty, 2020)
+#' One-mode undirected Friends character scene co-appearances (McNulty, 2020)
 #'
 #' @description
 #' One-mode network collected by \href{https://github.com/keithmcnulty/friends_analysis/}{McNulty (2020)}
 #' on the connections between the Friends TV series characters
 #' from Seasons 1 to 10.
-#' The `ison_friends` is a directed network
+#' The `fict_friends` is an undirected network
 #' containing connections between characters organised by season number,
 #' which is reflected in the tie attribute 'wave'.
 #' The network contains 650 nodes
 #' Each tie represents the connection between a character pair (appear in the same scene),
 #' and the 'weight' of the tie is the number of scenes the character pair appears in together.
 #' For all networks, characters are named (eg. Phoebe, Ross, Rachel).
-#' @details
-#' The data contains both networks but each may be used separately.
 #' @docType data
 #' @keywords datasets
-#' @name ison_friends
-#' @usage data(ison_friends)
+#' @name fict_friends
+#' @usage data(fict_friends)
 #' @references
 #'   McNulty, K. (2020).
 #'   \emph{Network analysis of Friends scripts.}.
 #' @format
 #'   ```{r, echo = FALSE}
-#'   ison_friends
+#'   fict_friends
 #'   ```
-"ison_friends"
+"fict_friends"
 
 ## Greys ####
 
@@ -639,14 +619,14 @@
 #'   
 #' @docType data
 #' @keywords datasets
-#' @name ison_greys
+#' @name fict_greys
 #' @author Gary Weissman and Benjamin Lind
-#' @usage data(ison_greys)
+#' @usage data(fict_greys)
 #' @format 
 #'   ```{r, echo = FALSE}
-#'   ison_greys
+#'   fict_greys
 #'   ```
-"ison_greys"
+"fict_greys"
 
 # Political ####
 
@@ -668,14 +648,14 @@
 #'   
 #' @docType data
 #' @keywords datasets
-#' @name ison_books
+#' @name irps_books
 #' @author Valdis Krebs, Mark Newman
-#' @usage data(ison_books)
+#' @usage data(irps_books)
 #' @format 
 #'   ```{r, echo = FALSE}
-#'   ison_books
+#'   irps_books
 #'   ```
-"ison_books"
+"irps_books"
 
 ## Blogs ####
 
@@ -684,6 +664,7 @@
 #' @description
 #'   This network consists of the blogosphere around the time of the 2004
 #'   US presidential election until February 2005.
+#'   The 2004 election was the first in which blogging played a significant role.
 #'   Ties were constructed from a crawl of the front page of each blog.
 #'   
 #'   Political leaning is indicated as "Liberal" (or left leaning) or 
@@ -692,14 +673,76 @@
 #'   based on incoming and outgoing links and posts.
 #' @docType data
 #' @keywords datasets
-#' @name ison_blogs
+#' @name irps_blogs
 #' @references
-#' Adamic, Lada A., and Natalie Glance. 2005.
-#' "The political blogosphere and the 2004 US Election", 
-#' _Proceedings of the WWW-2005 Workshop on the Weblogging Ecosystem_.
-#' @usage data(ison_blogs)
+#' Adamic, Lada, and Natalie Glance. 2005.
+#' "The political blogosphere and the 2004 US Election: Divided they blog". 
+#' _LinkKDD '05: Proceedings of the 3rd international workshop on Link discovery_, 36-43.
+#' \doi{10.1145/1134271.1134277}
+#' @usage data(irps_blogs)
 #' @format 
 #'   ```{r, echo = FALSE}
-#'   ison_blogs
+#'   irps_blogs
 #'   ```
-"ison_blogs"
+"irps_blogs"
+
+## WWI ####
+
+#' One-mode signed network of relationships between European major powers (Antal et al. 2006)
+#'
+#' @description
+#'   This network records the evolution of the major relationship changes
+#'   between the protagonists of World War I (WWI) from 1872 to 1907.
+#'   It is incomplete both in terms of (eventual) parties to the war as well
+#'   as some other relations, but gives a good overview of the main alliances
+#'   and enmities.
+#'   
+#'   The data series begins with the Three Emperors' League (1872, revived in 1881)
+#'   between Germany, Austria-Hungary, and Russia.
+#'   The Triple Alliance in 1882 joined Germany, Austria-Hungary, and Italy into
+#'   a bloc that lasted until WWI.
+#'   A bilateral alliance between Germany and Russia lapsed in 1890,
+#'   and a French-Russian alliance developed between 1891-1894.
+#'   The Entente Cordiale thawed and then fostered relations between Great Britain
+#'   and France in 1904, and a British-Russian agreement in 1907 bound
+#'   Great Britain, France, and Russia into the Triple Entente.
+#' @docType data
+#' @keywords datasets
+#' @name irps_wwi
+#' @references
+#' Antal, Tibor, Pavel Krapivsky, and Sidney Redner. 2006.
+#' "Social balance on networks: The dynamics of friendship and enmity". 
+#' _Physica D_ 224: 130-136.
+#' \doi{10.1016/j.physd.2006.09.028}
+#' @usage data(irps_wwi)
+#' @format 
+#'   ```{r, echo = FALSE}
+#'   irps_wwi
+#'   ```
+"irps_wwi"
+
+## US States ####
+
+#' One-mode undirected network of US state contiguity (Meghanathan 2017)
+#'
+#' @description
+#'   This network is of contiguity between US states.
+#'   States that share a border are connected by a tie in the network.
+#'   The data is a network of 107 ties among 50 US states (nodes).
+#'   States are named by their two-letter ISO-3166 code.
+#'   This data includes also the names of the capitol cities of each state,
+#'   which are listed in the node attribute 'capitol'.
+#' @docType data
+#' @keywords datasets
+#' @name irps_usgeo
+#' @usage data(irps_usgeo)
+#' @references
+#'   Meghanathan, Natarajan. 2017. 
+#'   "Complex network analysis of the contiguous United States graph." 
+#'   _Computer and Information Science_, 10(1): 54-76.
+#'   \doi{10.5539/cis.v10n1p54}
+#' @format
+#'   ```{r, echo = FALSE}
+#'   irps_usgeo
+#'   ```
+"irps_usgeo"
