@@ -49,7 +49,7 @@ net_core <- function(.data,
   if(is.null(mark)) mark <- node_is_core(.data)
   out <- stats::cor(c(as_matrix(.data)), 
                     c(as_matrix(create_core(.data, mark = mark))))
-  make_network_measure(out, .data)
+  make_network_measure(out, .data, call = deparse(sys.call()))
 }
 
 #' @rdname measure_features
@@ -100,7 +100,7 @@ net_richclub <- function(.data){
   coefs[is.nan(coefs)] <- 1
   out <- coefs[elbow_finder(seq_along(coefs), coefs)]
     # max(coefs, na.rm = TRUE)
-  make_network_measure(out, .data)
+  make_network_measure(out, .data, call = deparse(sys.call()))
 }
 
 #' @rdname measure_features 
@@ -118,7 +118,7 @@ net_factions <- function(.data,
   out <- stats::cor(c(manynet::as_matrix(.data)), 
                     c(manynet::as_matrix(manynet::create_components(.data,
                                                   membership = membership))))
-  make_network_measure(out, .data)
+  make_network_measure(out, .data, call = deparse(sys.call()))
 }
 
 #' @rdname measure_features
@@ -174,11 +174,12 @@ net_modularity <- function(.data,
   if(is_twomode(.data)){
     make_network_measure(igraph::modularity(to_multilevel(.data), 
                                           membership = membership,
-                                          resolution = resolution), .data)
+                                          resolution = resolution), 
+                         .data, call = deparse(sys.call()))
   } else make_network_measure(igraph::modularity(.data, 
                                                membership = membership,
                                                resolution = resolution),
-                              .data)
+                              .data, call = deparse(sys.call()))
 }
 
 #' @rdname measure_features 
@@ -264,7 +265,7 @@ net_smallworld <- function(.data,
                 "sigma" = (co/cr)/(lo/lr),
                 "SWI" = ((lo - ll)/(lr - ll))*((co - cr)/(cl - cr)))
   make_network_measure(out,
-                       .data)
+                       .data, call = deparse(sys.call()))
 }
 
 #' @rdname measure_features 
@@ -304,7 +305,8 @@ net_scalefree <- function(.data){
                 "could have been drawn from a power-law", 
                 "distribution rejected.\n"))
   }
-  make_network_measure(out$alpha, .data)
+  make_network_measure(out$alpha, .data, 
+                       call = deparse(sys.call()))
 }
 
 #' @rdname measure_features 
@@ -380,7 +382,8 @@ net_balance <- function(.data) {
   }
   tria_count <- count_signed_triangles(g)
   make_network_measure(unname((tria_count["+++"] + tria_count["+--"])/sum(tria_count)),
-                       .data)
+                       .data, 
+                       call = deparse(sys.call()))
 }
 
 
@@ -392,6 +395,7 @@ net_balance <- function(.data) {
 #'   
 #'   - `net_change()` measures the Hamming distance between two or more networks.
 #'   - `net_stability()` measures the Jaccard index of stability between two or more networks.
+#'   - `net_correlation()` measures the product-moment correlation between two networks.
 #' 
 #'   These `net_*()` functions return a numeric vector the length of the number
 #'   of networks minus one. E.g., the periods between waves.
@@ -436,4 +440,20 @@ net_stability <- function(.data, object2){
     n10 <- sum(net1 * net2==0)
     n11 / (n01 + n10 + n11)
   }, FUN.VALUE = numeric(1))
+}
+
+#' @rdname measure_periods 
+#' @export
+net_correlation <- function(.data, object2){
+  if(missing(.data)) {expect_nodes(); .data <- .G()}
+  comp1 <- as_matrix(.data)
+  comp2 <- as_matrix(object2)
+  if(!is_complex(.data)){
+    diag(comp1) <- NA
+  }
+  if(!is_directed(.data)){
+    comp1[upper.tri(comp1)] <- NA
+  }
+  out <- cor(c(comp1), c(comp2), use = "complete.obs")
+  make_network_measure(out, .data, call = deparse(sys.call()))
 }
\ No newline at end of file
