@@ -6,6 +6,9 @@
 #'   These functions offer algorithms for partitioning
 #'   networks into sets of communities:
 #' 
+#'   - `node_in_community()` runs either optimal or, for larger networks, 
+#'   finds the algorithm that maximises modularity and returns that membership
+#'   vector.
 #'   - `node_in_optimal()` is a problem-solving algorithm that seeks to maximise 
 #'   modularity over all possible partitions.
 #'   - `node_in_partition()` is a greedy, iterative, deterministic
@@ -29,6 +32,56 @@
 #' @family memberships
 NULL
 
+#' @rdname member_community_non 
+#' @section Community:
+#'   This function runs through all available community detection algorithms 
+#'   for a given network type, finds the algorithm that returns the
+#'   largest modularity score, and returns the corresponding membership
+#'   partition.
+#'   Where feasible (a small enough network), the optimal problem solving
+#'   technique is used to ensure the maximal modularity partition.
+#' @export
+node_in_community <- function(.data){
+  if(net_nodes(.data)<100){
+    # don't use node_in_betweenness because slow and poorer quality to optimal
+    mnet_success("{.fn node_in_optimal} available and", 
+                 "will return the highest modularity partition.")
+    node_in_optimal(.data)
+  } else {
+    poss_algs <- c("node_in_infomap",
+                   "node_in_spinglass",
+                   "node_in_fluid",
+                   "node_in_louvain",
+                   "node_in_leiden",
+                   "node_in_greedy",
+                   "node_in_eigen",
+                   "node_in_walktrap")
+    if(!manynet::is_connected(.data)){
+      notforconnected <- c("node_in_spinglass", 
+                           "node_in_fluid")
+      mnet_info("Excluding {.fn {notforconnected}} because network unconnected.")
+      poss_algs <- setdiff(poss_algs, notforconnected)
+    }
+    if(manynet::is_directed(.data)){
+      notfordirected <- c("node_in_louvain", 
+                          "node_in_leiden",
+                          "node_in_eigen")
+      mnet_info("Excluding {.fn {notfordirected}} because network directed.")
+      poss_algs <- setdiff(poss_algs, notfordirected)
+    }
+    mnet_info("Considering each of {.fn {poss_algs}}.")
+    candidates <- lapply(mnet_progress_along(poss_algs), function(comm){
+      memb <- get(poss_algs[comm])(.data)
+      mod <- net_modularity(.data, memb)
+      list(memb, mod)
+    })
+    mods <- unlist(sapply(candidates, "[", 2))
+    maxmod <- which.max(mods)
+    mnet_success("{.fn {poss_algs[maxmod]}} returns the highest modularity ({round(mods[maxmod],3)}).")
+    candidates[[maxmod]][[1]]
+  }
+}
+
 #' @rdname member_community_non 
 #' @section Optimal:
 #'   The general idea is to calculate the modularity of all possible partitions,
@@ -45,6 +98,9 @@ NULL
 #' @export
 node_in_optimal <- function(.data){
   if(missing(.data)) {expect_nodes(); .data <- .G()}
+  if(net_nodes(.data)>100) 
+    cli::cli_alert_danger(paste("This algorithm may take some time", 
+    "or even run out of memory on such a large network."))
   out <- igraph::cluster_optimal(manynet::as_igraph(.data)
   )$membership
   make_node_member(out, .data)
@@ -67,7 +123,7 @@ node_in_partition <- function(.data){
   n <- net_nodes(.data)
   group_size <- ifelse(n %% 2 == 0, n/2, (n+1)/2)
   
-  # count internal and external costs of each vertex
+  # count internal and external costs of each node
   g <- as_matrix(to_multilevel(.data))
   g1 <- g[1:group_size, 1:group_size]
   g2 <- g[(group_size+1):n, (group_size+1):n]
@@ -79,14 +135,14 @@ node_in_partition <- function(.data){
   g1.intcosts <- rowSums(g1)
   g1.extcosts <- rowSums(intergroup)
   
-  # count edge costs of each vertex
+  # count edge costs of each nodes
   g1.net <- g1.extcosts - g1.intcosts
   g2.net <- g2.extcosts - g2.intcosts
   
   g1.net <- sort(g1.net, decreasing = TRUE)
   g2.net <- sort(g2.net, decreasing = TRUE)
   
-  # swap pairs of vertices (one from each group) that give a positive sum of net edge costs
+  # swap pairs of nodes (one from each group) that give a positive sum of net tie costs
   if(length(g1.net)!=length(g2.net)) {
     g2.net <- c(g2.net,0)
   } else {g2.net}
@@ -168,11 +224,16 @@ node_in_infomap <- function(.data, times = 50){
 #' @export
 node_in_spinglass <- function(.data, max_k = 200, resolution = 1){
   if(missing(.data)) {expect_nodes(); .data <- .G()}
-  out <- igraph::cluster_spinglass(manynet::as_igraph(.data), 
-                                   spins = max_k, gamma = resolution,
-                                   implementation = ifelse(manynet::is_signed(.data), "neg", "orig")
-  )$membership
-  make_node_member(out, .data)
+  if(!igraph::is_connected(.data)) # note manynet::is_connected will return false
+    mnet_unavailable("This algorithm only works for connected networks.",
+                     "We suggest using `to_giant()`", 
+                     "to select the largest component.") else {
+      out <- igraph::cluster_spinglass(manynet::as_igraph(.data), 
+                                       spins = max_k, gamma = resolution,
+                                       implementation = ifelse(manynet::is_signed(.data), "neg", "orig")
+      )$membership
+      make_node_member(out, .data)
+    }
 }
 
 #' @rdname member_community_non 
@@ -195,13 +256,29 @@ node_in_spinglass <- function(.data, max_k = 200, resolution = 1){
 node_in_fluid <- function(.data) {
   if(missing(.data)) {expect_nodes(); .data <- .G()}
   .data <- as_igraph(.data)
-  mods <- vapply(seq.int(net_nodes(.data)), function(x)
-    igraph::modularity(.data, membership = igraph::membership(
-      igraph::cluster_fluid_communities(.data, x))),
-                 FUN.VALUE = numeric(1))
-  out <- igraph::membership(igraph::cluster_fluid_communities(
-    .data, no.of.communities = which.max(mods)))
-  make_node_member(out, .data)
+  if (!igraph::is_connected(.data)) {
+    mnet_unavailable("This algorithm only works for connected networks.",
+                     "We suggest using `to_giant()`", 
+                     "to select the largest component.")
+  } else {
+    if(is_complex(.data)){
+      mnet_info("This algorithm only works for simple networks.", 
+                      "Converting to simplex.")
+      .data <- to_simplex(.data)
+    }
+    if(is_directed(.data)){
+      mnet_info("This algorithm only works for undirected networks.", 
+                      "Converting to undirected")
+      .data <- to_undirected(.data)
+    }
+    mods <- vapply(seq_nodes(.data), function(x)
+      igraph::modularity(.data, membership = igraph::membership(
+        igraph::cluster_fluid_communities(.data, x))),
+      FUN.VALUE = numeric(1))
+    out <- igraph::membership(igraph::cluster_fluid_communities(
+      .data, no.of.communities = which.max(mods)))
+    make_node_member(out, .data)
+  }
 }
 
 #' @rdname member_community_non 
@@ -222,6 +299,11 @@ node_in_fluid <- function(.data) {
 #' @export
 node_in_louvain <- function(.data, resolution = 1){
   if(missing(.data)) {expect_nodes(); .data <- .G()}
+  if(is_directed(.data)){
+    mnet_info("This algorithm only works for undirected networks.", 
+              "Converting to undirected")
+    .data <- to_undirected(.data)
+  }
   out <- igraph::cluster_louvain(manynet::as_igraph(.data), 
                                 resolution = resolution
   )$membership
@@ -243,6 +325,8 @@ node_in_louvain <- function(.data, resolution = 1){
 #'   \eqn{n_i} is the node weight of node _i_,
 #'   and \eqn{\delta(\sigma_i, \sigma_j) = 1} if and only if
 #'   _i_ and _j_ are in the same communities and 0 otherwise.
+#'   Compared to the Louvain method, the Leiden algorithm additionally
+#'   tries to avoid unconnected communities.
 #' @references
 #' ## On Leiden community detection
 #' Traag, Vincent A., Ludo Waltman, and Nees Jan van Eck. 2019. 
@@ -254,6 +338,11 @@ node_in_louvain <- function(.data, resolution = 1){
 #' @export
 node_in_leiden <- function(.data, resolution = 1){
   if(missing(.data)) {expect_nodes(); .data <- .G()}
+  if(is_directed(.data)){
+    mnet_info("This algorithm only works for undirected networks.", 
+              "Converting to undirected")
+    .data <- to_undirected(.data)
+  }
   if(is_weighted(.data)){ # Traag resolution default
     n <- net_nodes(.data)
     resolution <- sum(tie_weights(.data))/(n*(n - 1)/2)
@@ -314,6 +403,9 @@ NULL
 #' @export
 node_in_betweenness <- function(.data){
   if(missing(.data)) {expect_nodes(); .data <- .G()}
+  if(net_nodes(.data)>100) 
+    cli::cli_alert_danger(paste("This algorithm may take some time", 
+                                "or even run out of memory on such a large network."))
   clust <- suppressWarnings(igraph::cluster_edge_betweenness(
     manynet::as_igraph(.data)))
   out <- clust$membership
@@ -373,6 +465,11 @@ node_in_greedy <- function(.data){
 #' @export
 node_in_eigen <- function(.data){
   if(missing(.data)) {expect_nodes(); .data <- .G()}
+  if(is_directed(.data)){
+    mnet_info("This algorithm only works for undirected networks.", 
+              "Converting to undirected")
+    .data <- to_undirected(.data)
+  }
   clust <- igraph::cluster_leading_eigen(as_igraph(.data))
   out <- clust$membership
   make_node_member(out, .data)
@@ -411,3 +508,27 @@ node_in_walktrap <- function(.data, times = 50){
   out
 }
 
+# #' @rdname member_community_hier 
+# #' @section Ensemble:
+# #'   Ensemble-based community detection runs community detection
+# #'   algorithms over multilayer or multiplex networks.
+# #' @references
+# #' ## On ensemble-based community detection
+# #' Tagarelli, Andrea, Alessia Amelio, and Francesco Gullo. 2017.
+# #' "Ensemble-based Community Detection in Multilayer Networks".
+# #' _Data Mining and Knowledge Discovery_, 31: 1506-1543.
+# #' \doi{10.1007/s10618-017-0528-8}
+# #' @examples
+# #' node_in_ensemble(ison_adolescents)
+# #' @export
+# node_in_ensemble <- function(.data, linkage_constraint = TRUE){
+#   if(missing(.data)) {expect_nodes(); .data <- .G()}
+#   clust <- igraph::cluster_walktrap(manynet::as_igraph(.data))
+#   out <- clust$membership
+#   make_node_member(out, .data)
+#   out <- make_node_member(out, .data)
+#   attr(out, "hc") <- stats::as.hclust(clust, 
+#                                       use.modularity = igraph::is_connected(.data))
+#   attr(out, "k") <- max(clust$membership)
+#   out
+# }
